@@ -1,8 +1,8 @@
 /** ===========================================================
  * @file
  *
- * This file is a part of digiKam project
- * <a href="http://www.digikam.org">http://www.digikam.org</a>
+ * This file is a part of KDE project
+ *
  *
  * @date   2011-01-12
  * @brief  Merges tiles into groups
@@ -43,7 +43,7 @@ public:
 
     Private()
         : clustersDirty(true),
-          currentBackend(0)
+          currentBackend(nullptr)
     {
 
     }
